Crate loadsmith_platform

Crate loadsmith_platform 

Platform and game detection for the loadsmith mod-manager library.

This is an internal crate of the [loadsmith] workspace. Most consumers should depend on the loadsmith facade crate instead of using this crate directly.

Enums

Error
Errors that can occur during platform and game detection.
Platform
A game distribution platform.

Functions

find_executables
Walk a game directory tree and yield paths to executable files.
guess_proton
Guess whether a game is running under Proton (Linux Steam Play).
try_guess_proton
Guess whether a game is running under Proton (Linux Steam Play), returning errors.

Type Aliases

Result
Alias for Result<T, Error> in the loadsmith-platform crate.