Platform and game detection for the loadsmith mod-manager library.
This is an internal crate of the [loadsmith] workspace. Most consumers
should depend on the loadsmith facade crate instead of using this
crate directly.
Enums
Functions
- find_
executables - Walk a game directory tree and yield paths to executable files.
- guess_
proton - Guess whether a game is running under Proton (Linux Steam Play).
- try_
guess_ proton - Guess whether a game is running under Proton (Linux Steam Play), returning errors.
Type Aliases
- Result
- Alias for
Result<T, Error>in the loadsmith-platform crate.